ReaderMask

Type Alias ReaderMask 

pub type ReaderMask = u32;
Bitmap (32 bit) — one bit per reader slot. Bit set = reader has read. The slot becomes reservable again when all active reader bits are set, or the timeout has elapsed.